
Single input validation controls
-------

**Description:**

Input validation refers to the process of validating all the input to an application
 before using it. Input validation is absolutely critical to application security, 
 and most application risks involve tainted input at some level.


**Solution:**

Verify that a single input validation control is used by the application for each 
type of data that is accepted.

	